==> haskell-regex-applicative-0.3.4-292.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
key:                  regex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  682527621392e08c941b80cbbce909c8
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
depends:
    base-4.18.2.1 containers-0.6.7
    filtrable-0.1.6.0-IOYZfNkyhv6IpXIpnLCXcC transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.4-293-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-4QdTBqQAZ4mDJnVX7OUMhV
key:                  regex-applicative-0.3.4-4QdTBqQAZ4mDJnVX7OUMhV
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  7496610b24f1274a0c2662952036f2da
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-4QdTBqQAZ4mDJnVX7OUMhV
depends:
    base-4.18.2.1 containers-0.6.7
    filtrable-0.1.6.0-8bdKxzzk7McKxAYa1UD30S transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
